.. _fact:


.. raw:: html

    <br>
    <center>

(f)act
======

.. raw:: html

    </center>
    <br>

Brengt het toedienen van gif levensgevaar, het nalaten de noodzakelijke verpleging te leveren brengt de dood:

1. Off-label toedienen.

   Off-label toedienen houd in dat er of buiten de toegestaande bloedspiegels toegedient word of dat het medicijnen voor een andere ziekte word toegedient dan waarvoor hij getest is. Dient men hogere waardes toe dan toegestaan dan is men aan het vergiftigen. Dat een arts heden ten dage uberhaupt Off-label mag toedienen is al belachelijk (want per definitie vergiftiging).

   Gif toedieningen dienen vervolgt te worden. 

2. Onder de ondergrens toedienen.

   Deze dodelijke stoffen hebben boven EN onder grenzen wat betreft bloedspiegels, depletie (het ontbreken van stoffen) is ook levensbedreigend.

   De rechter mag alleen nog afbouwplannen goedkeuren.

3. Ontkennen dat men dodelijke stoffen toedient.

   Als een arts ontkent dat hij dodelijke stoffen toedient, dient hij MEER toe van die stof als de patient onstabiel word. I.p.v. de medicijnen af te bouwen, dient hij meer toe. De horror voor het slachtoffer dat in een toestand van vergiftiging meer gif krijgt toegedient.

   Het schadelijke karakter van een product ontkennen is strafbaar.

4. Bloedspiegel van een medicijn niet meten.

   Als een arts niet de bloedspiegels van een medicijn meet is hij niet op de hoogte van de toestand van de patient en kan dus ook geen goed oordeel vellen over het ziektebeeld van de patient. De arts probeert maar wat.

   Bloedmetingen voordat er een diagnose gepleegd word zouden verplicht moeten worden. 

5. Symptomen van een vergiftiging niet (willen) zien.

   Als een arts al dodelijk stoffen toedient en dat zelf niet wil erkennen is het voor hem ook onmogelijk om symptomen die ontstaan door het toedienen van dodelijke stoffen aan de dodelijke stoffen toe te kennen. Als een arts niet symptomen van vergiftiging erkent, komt de patient in een neerwaartse spiraal terecht waarbij zijn toestand met de dag verslechterd.

   Zou een wet tegen ontkenning van gif ook moeten voorkomen.   

6. Eerst een afspraak maken voordat je een crisis kan melden,in het weekend en avonduren niet beschikbaar.

   De (F)ACT teams die de toediening van dodelijke stoffen verantwoord zouden moeten doen, zijn er in het weekend niet, in de avonduren niet, laten je een afspraak maken dat je een crisis mag melden, doen alles om maar niet te hoefen reageren om hulproepen van hun slachtoffers. Het niet aanwezig zijn van de noodzakelijke verpleging als met met dodelijke stoffen behandelt brengt wanhoop en paniek bij de slachtoffers die voor hun leven moeten vrezen.

   Verplichte herinvoering van 24/7 door huisartsen en niet HAP is weer de behandelaar verantwoordelijk maken voor de behandeling.

7. Pas zorgverlenen als de ellende al gebeurd is.

   Men werkt met het principe van “stepped-care”, geschakelde zorg, waarbij men meer zorg levert naar gelang de toestand van het slachtoffer daar omvraagt. Dit maakt dat men altijd eerst de ellende laat gebeuren, waarna men pas extra zorg inschakelt. Wat men hier bezigt is “budget overschot is winst”, de zorg die men niet levert kan men als winst inboeken.

   De SPV-er/casemanager in de basisverzekering is nodig.

8. Symptomen zelf bijhouden.

   De controle op de geleverde verpleging is zo slecht dat het aan een slachtoffer is om bij te houden hoe het met toename/afname van symptomen gaat. Het slachtoffer is echter helemaal niet in staat om symptomen bij te houden, het is aan de mantelzorger om te constateren dat een slachtoffer in een toestand van vergiftiging verkeerd.

   Ik probeer dit programma zo te maken dat men symptomen ook kan loggen.

9. Oordeel “geen crisis”

   Het toedienen van gif onder onverantwoorde omstandigheden maakt dat het slachtoffer in levensbedreigende situaties terecht komt. Deze door de “zorg” gegenereerde levensbedreiging is waar het slachtoffer mee te maken krijgt. Wel symptomen van dodelijke aandoeningen dan oordelen dat er geen opname nodig is, maakt dat noodzakelijke medische hulp hierbij word ontzegt.

   Iemand de noodzakelijke hulp bij vergiftiging ontzeggen vind ik inhumaan.

10. Behandelplan niet ingevuld.

    Bij de behandeling door de GGZ word er zo min mogelijk aan verplichtingen opgeschreven in het behandelplan zodat er ook geen claims tot prestatie gemaakt kunnen worden. 

    Volledig ingevulde behandelplannen zouden een vereiste moeten zijn voor behandeling.
